window.Gleam.initSearch([{"doc":"bravo","title":"bravo","content":"# bravo\n### [v2.2.1](https://github.com/Michael-Mark-Edu/bravo/blob/main/CHANGELOG.md#v221)\n\n[![Package Version](https://img.shields.io/hexpm/v/bravo)](https://hex.pm/packages/bravo)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/bravo/)\n\n~~Comprehensive~~ Very much incomplete (for now) ETS bindings for Gleam.\n\nThis library is only compatible with the Erlang target!\n\n## What is an ETS?\n\nETS stands for Erlang Term Storage, and it is a data structure that stores collections of data\n(objects) that are addressable by keys.\n\n### Why should I use ETS over, say, a `Dict`?\n\nETS tables have the following properties that make them distinct from `Dict`s:\n- ETS tables are not garbage collected, allowing them to be accessed from anywhere in a process\n  without needing to pass return values around. This does come at the cost of forcing the user\n  to manually delete the table once they are done with it.\n- ETS tables offer a wide array of customization options that `Dict`s do not, such as the options\n  to be ordered, allow multiple objects per key, which element of the object acts as the key,\n  and controlling read/write access from external processes.\n- ETS tables offer increased functionality compared to `Dict`s, natively allowing functions such as\n  complex searching, reading/writing the ETS to a file, and having much more complex entries.\n- ETS tables work well with concurrency.\n\n### Why should I use Bravo over other libraries such as Carpenter?\n\nA difficulty of implementing ETS tables in Gleam is that Gleam is a statically-typed language and\nETS tables are very much designed for the dynamically-typed Erlang. Carpenter ensures type safety\nby restricting objects to simple key-value pairs, much like a `Dict`.\n\nBravo, however, does not impose much of any restriction at all. The only restriction that is in\nplace is that all objects in a table must have the same type, but that type can be literally\nanything. In an earlier version of this package, even this wasn&#39;t a restriction, but that resulted\nin unsafe and un-Gleamlike code.\n\nA goal of Bravo is to be fully comprehensive, meaning that I intend on implementing every single\nETS function into the library. This goal may very well be infeasible, but I will pursue it anyway.\n\n## Installation\nBravo depends on the `gleam_erlang` package, but otherwise does not have any other dependency.\n\n```sh\ngleam add bravo gleam_erlang\n```\n\n## Usage\n```gleam\nimport bravo/etc\nimport bravo/uset\nimport gleam/io\nimport gleam/option.{Some}\n\npub fn main() {\n  // Create a new ETS table. There are multiple options, but here we are using\n  // a USet (an alias for &quot;set&quot; in Erlang terms)\n  let assert Ok(table) = uset.new(&quot;MyTable&quot;, 1, etc.Public)\n\n  // We can then insert tuples into this table\n  uset.insert(table, [#(&quot;Hello&quot;, &quot;world!&quot;)])\n\n  // Then we can lookup the object from the table\n  let assert Some(object) = uset.lookup(table, &quot;Hello&quot;)\n  io.print(object.0 &lt;&gt; &quot;, &quot; &lt;&gt; object.1) // &quot;Hello, world!&quot;\n\n  // ETS tables have static lifetimes,\n  // so don&#39;t forget to delete them when you&#39;re done!\n  uset.delete(table)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/bravo&gt;.\n","url":"index.html"},{"doc":"bravo/etc","title":"Access","content":"pub type Access {\n  Public\n  Protected\n  Private\n}\n Access specifiers for ETS tables. Affects how other processes can interact with the table.\n\nPublic\n Any process can read or write to the `USet`.\n\nProtected\n Any process can read the `USet`. Only the owner process can write to it.\n\nPrivate\n Only the parent process can read or write to the `USet`.\n\nSynonyms:\nbravo/etc.Access\nbravo/etc Access","url":"bravo/etc.html#Access"},{"doc":"bravo/etc","title":"Term","content":"pub type Term\n Represents an Erlang `term()`, which can represent any data type.\n\n\nSynonyms:\nbravo/etc.Term\nbravo/etc Term","url":"bravo/etc.html#Term"},{"doc":"bravo/etc","title":"bravo/etc","content":" This module provides types or functions that don&#39;t fit anywhere else.","url":"bravo/etc.html"},{"doc":"bravo/error","title":"ErlangError","content":"pub type ErlangError {\n  Badarg\n  Badarith\n  Badmatch(Term)\n  FunctionClause\n  CaseClause(Term)\n  IfClause\n  TryClause(Term)\n  Undef\n  Badfun(Term)\n  Badarity(#(Term, Term))\n  TimeoutValue\n  Noproc\n  Noconnection\n  Nocatch(Term)\n  SystemLimit\n}\n Represents any of Erlang&#39;s runtime errors. These errors are often vague and unclear.\n\nBadarg\n\n\nBadarith\n\n\nBadmatch(Term)\n\n\nFunctionClause\n\n\nCaseClause(Term)\n\n\nIfClause\n\n\nTryClause(Term)\n\n\nUndef\n\n\nBadfun(Term)\n\n\nBadarity(#(Term, Term))\n\n\nTimeoutValue\n\n\nNoproc\n\n\nNoconnection\n\n\nNocatch(Term)\n\n\nSystemLimit\n\n\nSynonyms:\nbravo/error.ErlangError\nbravo/error ErlangError","url":"bravo/error.html#ErlangError"},{"doc":"bravo/error","title":"bravo/error","content":" This module provides error types specific to Bravo. Currently, this only includes `ErlangError`","url":"bravo/error.html"},{"doc":"bravo/bag","title":"Bag","content":"pub opaque type Bag(t)\n A bag table. Keys may occur multiple times per table, but objects cannot be copied verbatim.\n\n\nSynonyms:\nbravo/bag.Bag\nbravo/bag Bag","url":"bravo/bag.html#Bag"},{"doc":"bravo/bag","title":"delete","content":"pub fn delete(bag: Bag(a)) -&gt; Bool\n Deletes a `Bag`.\n\n Table lifetime is static, and memory is only freed when the owner process is killed! Don&#39;t forget to call this function!\n\nSynonyms:\nbravo/bag.delete\nbravo/bag delete","url":"bravo/bag.html#delete"},{"doc":"bravo/bag","title":"delete_all_objects","content":"pub fn delete_all_objects(bag: Bag(a)) -&gt; Nil\n Deletes all objects in the `Bag`. This is atomic and isolated.\n\nSynonyms:\nbravo/bag.delete_all_objects\nbravo/bag delete_all_objects","url":"bravo/bag.html#delete_all_objects"},{"doc":"bravo/bag","title":"delete_key","content":"pub fn delete_key(bag: Bag(a), key: b) -&gt; Nil\n Deletes all objects addressed by `key`, if any exist. If nothing does, this does nothing.\n\nSynonyms:\nbravo/bag.delete_key\nbravo/bag delete_key","url":"bravo/bag.html#delete_key"},{"doc":"bravo/bag","title":"delete_object","content":"pub fn delete_object(bag: Bag(a), object: a) -&gt; Nil\n Deletes a specific object in the `Bag`. Other objects with the same key are unaffected.\n\nSynonyms:\nbravo/bag.delete_object\nbravo/bag delete_object","url":"bravo/bag.html#delete_object"},{"doc":"bravo/bag","title":"file2tab","content":"pub fn file2tab(\n  filename: String,\n  verify: Bool,\n  decoder: fn(Dynamic) -&gt; Result(a, b),\n) -&gt; Option(Bag(a))\n Creates a `Bag` from file `filename` that was previously created by `tab2file`.\n\n For type safety reasons, a dynamic decoder must be provided, and the decoder must not fail for all objects in the table.\n\n If the flag `verify` is set, then checks are performed to ensure the data is correct. This can be slow if `tab2file` was ran with `md5sum` enabled.\n\nSynonyms:\nbravo/bag.file2tab\nbravo/bag file2tab","url":"bravo/bag.html#file2tab"},{"doc":"bravo/bag","title":"insert","content":"pub fn insert(bag: Bag(a), objects: List(a)) -&gt; Bool\n Inserts a list of tuples into a `Bag`.\n\n Returns a `Bool` representing if the inserting succeeded.\n - If `True`, all objects in the list were inserted.\n - If `False`, _none_ of the objects in the list were inserted. This may occur if the `keypos` of the `Bag` is greater than the object tuple size or if the input list is empty.\n\n If an object with the same key already exists, then the old object will be overwritten with the new one.\n\nSynonyms:\nbravo/bag.insert\nbravo/bag insert","url":"bravo/bag.html#insert"},{"doc":"bravo/bag","title":"lookup","content":"pub fn lookup(bag: Bag(a), key: b) -&gt; List(a)\n Gets a list of objects from a `Bag`.\n\n Returns an list containing the objects, if any match.\n\nSynonyms:\nbravo/bag.lookup\nbravo/bag lookup","url":"bravo/bag.html#lookup"},{"doc":"bravo/bag","title":"new","content":"pub fn new(\n  name: String,\n  keypos: Int,\n  access: Access,\n) -&gt; Result(Bag(a), Option(ErlangError))\n Creates a new ETS table configured as a bag: keys may only occur multiple times per table, but objects cannot be copied verbatim.\n\n `name`: An atom representing the name of the `Bag`. There may only be one ETS table associated with an atom.\n `keypos`: The index (1-indexed) that represents the key position of the object. This function fails if this is less than 1.\n `access`: Determines how visible the table is to other processes.\n - `Public`: Any process can read or write to the `Bag`.\n - `Protected`: Any process can read the `Bag`. Only the owner process can write to it.\n - `Private`: Only the parent process can read or write to the `Bag`.\n\n Returns a result of the created `Bag`, which can be used by other functions in this module.\n If this function errors with `None`, then you likely put in an illegal `keypos` value.\n Otherwise, something went wrong in the FFI layer and an error occured in Erlang land.\n\nSynonyms:\nbravo/bag.new\nbravo/bag new","url":"bravo/bag.html#new"},{"doc":"bravo/bag","title":"tab2file","content":"pub fn tab2file(\n  bag: Bag(a),\n  filename: String,\n  object_count: Bool,\n  md5sum: Bool,\n  sync: Bool,\n) -&gt; Bool\n Saves a `Bag` as file `filename` that can later be read back into memory using `file2tab`.\n\n There are three configuration flags with this function:\n - `object_count`: Stores the number of objects in the table in the footer. This can detect truncation.\n - `md5sum`: Stores a md5 checksum of the table and its objects. This can detect even single bitflips, but is computationally expensive.\n - `sync`: Blocks the process until the file has been successfully written.\n\nSynonyms:\nbravo/bag.tab2file\nbravo/bag tab2file","url":"bravo/bag.html#tab2file"},{"doc":"bravo/bag","title":"tab2list","content":"pub fn tab2list(bag: Bag(a)) -&gt; List(a)\n Returns a list containing all of the objects in the `Bag`.\n\nSynonyms:\nbravo/bag.tab2list\nbravo/bag tab2list","url":"bravo/bag.html#tab2list"},{"doc":"bravo/bag","title":"bravo/bag","content":" This module provides functions to work with `Bag`s","url":"bravo/bag.html"},{"doc":"bravo/dbag","title":"DBag","content":"pub opaque type DBag(t)\n A duplicate bag etc. Keys may occur multiple times per table, and verbatim copies of an object can be stored.\n\n\nSynonyms:\nbravo/dbag.DBag\nbravo/dbag DBag","url":"bravo/dbag.html#DBag"},{"doc":"bravo/dbag","title":"delete","content":"pub fn delete(dbag: DBag(a)) -&gt; Bool\n Deletes a `DBag`.\n\n Table lifetime is static, and memory is only freed when the owner process is killed! Don&#39;t forget to call this function!\n\nSynonyms:\nbravo/dbag.delete\nbravo/dbag delete","url":"bravo/dbag.html#delete"},{"doc":"bravo/dbag","title":"delete_all_objects","content":"pub fn delete_all_objects(dbag: DBag(a)) -&gt; Nil\n Deletes all objects in the `DBag`. This is atomic and isolated.\n\nSynonyms:\nbravo/dbag.delete_all_objects\nbravo/dbag delete_all_objects","url":"bravo/dbag.html#delete_all_objects"},{"doc":"bravo/dbag","title":"delete_key","content":"pub fn delete_key(dbag: DBag(a), key: b) -&gt; Nil\n Deletes all objects addressed by `key`, if any exist. If nothing does, this does nothing.\n\nSynonyms:\nbravo/dbag.delete_key\nbravo/dbag delete_key","url":"bravo/dbag.html#delete_key"},{"doc":"bravo/dbag","title":"delete_object","content":"pub fn delete_object(dbag: DBag(a), object: a) -&gt; Nil\n Deletes a specific object in the `DBag`. Other objects with the same key are unaffected.\n\n If there are multiple of the same object, then they will all be deleted.\n\nSynonyms:\nbravo/dbag.delete_object\nbravo/dbag delete_object","url":"bravo/dbag.html#delete_object"},{"doc":"bravo/dbag","title":"file2tab","content":"pub fn file2tab(\n  filename: String,\n  verify: Bool,\n  decoder: fn(Dynamic) -&gt; Result(a, b),\n) -&gt; Option(DBag(a))\n Creates a `Ddbag` from file `filename` that was previously created by `tab2file`.\n\n For type safety reasons, a dynamic decoder must be provided, and the decoder must not fail for all objects in the table.\n\n If the flag `verify` is set, then checks are performed to ensure the data is correct. This can be slow if `tab2file` was ran with `md5sum` enabled.\n\nSynonyms:\nbravo/dbag.file2tab\nbravo/dbag file2tab","url":"bravo/dbag.html#file2tab"},{"doc":"bravo/dbag","title":"insert","content":"pub fn insert(dbag: DBag(a), objects: List(a)) -&gt; Bool\n Inserts a list of tuples into a `DBag`.\n\n Returns a `Bool` representing if the inserting succeeded.\n - If `True`, all objects in the list were inserted.\n - If `False`, _none_ of the objects in the list were inserted. This may occur if the `keypos` of the `DBag` is greater than the object tuple size or if the input list is empty.\n\n If an object with the same key already exists, then the old object will be overwritten with the new one.\n\nSynonyms:\nbravo/dbag.insert\nbravo/dbag insert","url":"bravo/dbag.html#insert"},{"doc":"bravo/dbag","title":"lookup","content":"pub fn lookup(dbag: DBag(a), key: b) -&gt; List(a)\n Gets a list of objects from a `DBag`.\n\n Returns an list containing the objects, if any match.\n\nSynonyms:\nbravo/dbag.lookup\nbravo/dbag lookup","url":"bravo/dbag.html#lookup"},{"doc":"bravo/dbag","title":"new","content":"pub fn new(\n  name: String,\n  keypos: Int,\n  access: Access,\n) -&gt; Result(DBag(a), Option(ErlangError))\n Creates a new ETS table configured as a duplicate bag: keys may occur multiple times per table, and verbatim copies of an object can be stored.\n\n `name`: An atom representing the name of the `DBag`. There may only be one ETS table associated with an atom.\n `keypos`: The index (1-indexed) that represents the key position of the object. This function fails if this is less than 1.\n `access`: Determines how visible the table is to other processes.\n - `Public`: Any process can read or write to the `DBag`.\n - `Protected`: Any process can read the `DBag`. Only the owner process can write to it.\n - `Private`: Only the parent process can read or write to the `DBag`.\n\n Returns a result of the created `DBag`, which can be used by other functions in this module.\n If this function errors with `None`, then you likely put in an illegal `keypos` value.\n Otherwise, something went wrong in the FFI layer and an error occured in Erlang land.\n\nSynonyms:\nbravo/dbag.new\nbravo/dbag new","url":"bravo/dbag.html#new"},{"doc":"bravo/dbag","title":"tab2file","content":"pub fn tab2file(\n  dbag: DBag(a),\n  filename: String,\n  object_count: Bool,\n  md5sum: Bool,\n  sync: Bool,\n) -&gt; Bool\n Saves a `Ddbag` as file `filename` that can later be read back into memory using `file2tab`.\n\n There are three configuration flags with this function:\n - `object_count`: Stores the number of objects in the table in the footer. This can detect truncation.\n - `md5sum`: Stores a md5 checksum of the table and its objects. This can detect even single bitflips, but is computationally expensive.\n - `sync`: Blocks the process until the file has been successfully written.\n\nSynonyms:\nbravo/dbag.tab2file\nbravo/dbag tab2file","url":"bravo/dbag.html#tab2file"},{"doc":"bravo/dbag","title":"tab2list","content":"pub fn tab2list(dbag: DBag(a)) -&gt; List(a)\n Returns a list containing all of the objects in the `Ddbag`.\n\nSynonyms:\nbravo/dbag.tab2list\nbravo/dbag tab2list","url":"bravo/dbag.html#tab2list"},{"doc":"bravo/dbag","title":"bravo/dbag","content":" This module provides functions to work with `DBag`s\n","url":"bravo/dbag.html"},{"doc":"bravo/oset","title":"OSet","content":"pub opaque type OSet(t)\n An ordered set. Keys may only occur once per table, and objects are ordered (this comes at a performance cost).\n\n In order for a lookup match to occur, entries must _coerce into the same value_. Two values may match even if they have different types.\n\n\nSynonyms:\nbravo/oset.OSet\nbravo/oset OSet","url":"bravo/oset.html#OSet"},{"doc":"bravo/oset","title":"delete","content":"pub fn delete(oset: OSet(a)) -&gt; Bool\n Deletes a `OSet`.\n\n Table lifetime is static, and memory is only freed when the owner process is killed! Don&#39;t forget to call this function!\n\nSynonyms:\nbravo/oset.delete\nbravo/oset delete","url":"bravo/oset.html#delete"},{"doc":"bravo/oset","title":"delete_all_objects","content":"pub fn delete_all_objects(oset: OSet(a)) -&gt; Nil\n Deletes all objects in the `OSet`. This is atomic and isolated.\n\nSynonyms:\nbravo/oset.delete_all_objects\nbravo/oset delete_all_objects","url":"bravo/oset.html#delete_all_objects"},{"doc":"bravo/oset","title":"delete_key","content":"pub fn delete_key(oset: OSet(a), key: b) -&gt; Nil\n Deletes the object addressed by `key`, if it exists. If it doesn&#39;t, this does nothing.\n\nSynonyms:\nbravo/oset.delete_key\nbravo/oset delete_key","url":"bravo/oset.html#delete_key"},{"doc":"bravo/oset","title":"delete_object","content":"pub fn delete_object(oset: OSet(a), object: a) -&gt; Nil\n Deletes a specific object in the `OSet`. This is more useful in `Bag`s and `DBag`s.\n\nSynonyms:\nbravo/oset.delete_object\nbravo/oset delete_object","url":"bravo/oset.html#delete_object"},{"doc":"bravo/oset","title":"file2tab","content":"pub fn file2tab(\n  filename: String,\n  verify: Bool,\n  decoder: fn(Dynamic) -&gt; Result(a, b),\n) -&gt; Option(OSet(a))\n Creates a `OSet` from file `filename` that was previously created by `tab2file`.\n\n For type safety reasons, a dynamic decoder must be provided, and the decoder must not fail for all objects in the table.\n\n If the flag `verify` is set, then checks are performed to ensure the data is correct. This can be slow if `tab2file` was ran with `md5sum` enabled.\n\nSynonyms:\nbravo/oset.file2tab\nbravo/oset file2tab","url":"bravo/oset.html#file2tab"},{"doc":"bravo/oset","title":"insert","content":"pub fn insert(oset: OSet(a), objects: List(a)) -&gt; Bool\n Inserts a list of tuples into a `OSet`.\n\n Returns a `Bool` representing if the inserting succeeded.\n - If `True`, all objects in the list were inserted.\n - If `False`, _none_ of the objects in the list were inserted. This may occur if the `keypos` of the `OSet` is greater than the object tuple size or if the input list is empty.\n\n If an object with the same key already exists, then the old object will be overwritten with the new one.\n\nSynonyms:\nbravo/oset.insert\nbravo/oset insert","url":"bravo/oset.html#insert"},{"doc":"bravo/oset","title":"lookup","content":"pub fn lookup(oset: OSet(a), key: b) -&gt; Option(a)\n Gets an object from a `OSet`.\n\n Returns an `Option` containing the object, if it exists.\n\nSynonyms:\nbravo/oset.lookup\nbravo/oset lookup","url":"bravo/oset.html#lookup"},{"doc":"bravo/oset","title":"new","content":"pub fn new(\n  name: String,\n  keypos: Int,\n  access: Access,\n) -&gt; Result(OSet(a), Option(ErlangError))\n Creates a new ETS table configured as an ordered set: keys may only occur once per table, and objects are ordered (this comes at a performance cost).\n\n `name`: An atom representing the name of the `OSet`. There may only be one ETS table associated with an atom.\n `keypos`: The index (1-indexed) that represents the key position of the object. This function fails if this is less than 1.\n `access`: Determines how visible the table is to other processes.\n - `Public`: Any process can read or write to the `OSet`.\n - `Protected`: Any process can read the `OSet`. Only the owner process can write to it.\n - `Private`: Only the parent process can read or write to the `OSet`.\n\n Returns a result of the created `OSet`, which can be used by other functions in this module.\n If this function errors with `None`, then you likely put in an illegal `keypos` value.\n Otherwise, something went wrong in the FFI layer and an error occured in Erlang land.\n\nSynonyms:\nbravo/oset.new\nbravo/oset new","url":"bravo/oset.html#new"},{"doc":"bravo/oset","title":"tab2file","content":"pub fn tab2file(\n  oset: OSet(a),\n  filename: String,\n  object_count: Bool,\n  md5sum: Bool,\n  sync: Bool,\n) -&gt; Bool\n Saves a `OSet` as file `filename` that can later be read back into memory using `file2tab`.\n\n There are three configuration flags with this function:\n - `object_count`: Stores the number of objects in the table in the footer. This can detect truncation.\n - `md5sum`: Stores a md5 checksum of the table and its objects. This can detect even single bitflips, but is computationally expensive.\n - `sync`: Blocks the process until the file has been successfully written.\n\nSynonyms:\nbravo/oset.tab2file\nbravo/oset tab2file","url":"bravo/oset.html#tab2file"},{"doc":"bravo/oset","title":"tab2list","content":"pub fn tab2list(oset: OSet(a)) -&gt; List(a)\n Returns a list containing all of the objects in the `OSet`.\n\n The list returned is ordered.\n\nSynonyms:\nbravo/oset.tab2list\nbravo/oset tab2list","url":"bravo/oset.html#tab2list"},{"doc":"bravo/oset","title":"bravo/oset","content":" This module provides functions to work with `OSet`s","url":"bravo/oset.html"},{"doc":"bravo/uset","title":"USet","content":"pub opaque type USet(t)\n An unordered set. Keys may only occur once per table, and objects are unordered.\n\n In order for a lookup match to occur, entries must have the same value _and type_.\n\n\nSynonyms:\nbravo/uset.USet\nbravo/uset USet","url":"bravo/uset.html#USet"},{"doc":"bravo/uset","title":"delete","content":"pub fn delete(uset: USet(a)) -&gt; Bool\n Deletes a `USet`.\n\n Table lifetime is static, and memory is only freed when the owner process is killed! Don&#39;t forget to call this function!\n\nSynonyms:\nbravo/uset.delete\nbravo/uset delete","url":"bravo/uset.html#delete"},{"doc":"bravo/uset","title":"delete_all_objects","content":"pub fn delete_all_objects(uset: USet(a)) -&gt; Nil\n Deletes all objects in the `USet`. This is atomic and isolated.\n\nSynonyms:\nbravo/uset.delete_all_objects\nbravo/uset delete_all_objects","url":"bravo/uset.html#delete_all_objects"},{"doc":"bravo/uset","title":"delete_key","content":"pub fn delete_key(uset: USet(a), key: b) -&gt; Nil\n Deletes the object addressed by `key`, if it exists. If it doesn&#39;t, this does nothing.\n\nSynonyms:\nbravo/uset.delete_key\nbravo/uset delete_key","url":"bravo/uset.html#delete_key"},{"doc":"bravo/uset","title":"delete_object","content":"pub fn delete_object(uset: USet(a), object: a) -&gt; Nil\n Deletes a specific object in the `USet`. This is more useful in `Bag`s and `DBag`s.\n\nSynonyms:\nbravo/uset.delete_object\nbravo/uset delete_object","url":"bravo/uset.html#delete_object"},{"doc":"bravo/uset","title":"file2tab","content":"pub fn file2tab(\n  filename: String,\n  verify: Bool,\n  decoder: fn(Dynamic) -&gt; Result(a, b),\n) -&gt; Option(USet(a))\n Creates a `USet` from file `filename` that was previously created by `tab2file`.\n\n For type safety reasons, a dynamic decoder must be provided, and the decoder must not fail for all objects in the table.\n\n If the flag `verify` is set, then checks are performed to ensure the data is correct. This can be slow if `tab2file` was ran with `md5sum` enabled.\n\nSynonyms:\nbravo/uset.file2tab\nbravo/uset file2tab","url":"bravo/uset.html#file2tab"},{"doc":"bravo/uset","title":"insert","content":"pub fn insert(uset: USet(a), objects: List(a)) -&gt; Bool\n Inserts a list of tuples into a `USet`.\n\n Returns a `Bool` representing if the inserting succeeded.\n - If `True`, all objects in the list were inserted.\n - If `False`, _none_ of the objects in the list were inserted. This may occur if the `keypos` of the `USet` is greater than the object tuple size or if the input list is empty.\n\n If an object with the same key already exists, then the old object will be overwritten with the new one.\n\nSynonyms:\nbravo/uset.insert\nbravo/uset insert","url":"bravo/uset.html#insert"},{"doc":"bravo/uset","title":"lookup","content":"pub fn lookup(uset: USet(a), key: b) -&gt; Option(a)\n Gets an object from a `USet`.\n\n Returns an `Option` containing the object, if it exists.\n\nSynonyms:\nbravo/uset.lookup\nbravo/uset lookup","url":"bravo/uset.html#lookup"},{"doc":"bravo/uset","title":"new","content":"pub fn new(\n  name: String,\n  keypos: Int,\n  access: Access,\n) -&gt; Result(USet(a), Option(ErlangError))\n Creates a new ETS table configured as a set: keys may only occur once per table, and objects are unordered.\n\n `name`: An atom representing the name of the `USet`. There may only be one ETS table associated with an atom.\n `keypos`: The index (1-indexed) that represents the key position of the object. This function fails if this is less than 1.\n `access`: Determines how visible the table is to other processes.\n - `Public`: Any process can read or write to the `USet`.\n - `Protected`: Any process can read the `USet`. Only the owner process can write to it.\n - `Private`: Only the parent process can read or write to the `USet`.\n\n Returns a result of the created `USet`, which can be used by other functions in this module.\n If this function errors with `None`, then you likely put in an illegal `keypos` value.\n Otherwise, something went wrong in the FFI layer and an error occured in Erlang land.\n\nSynonyms:\nbravo/uset.new\nbravo/uset new","url":"bravo/uset.html#new"},{"doc":"bravo/uset","title":"tab2file","content":"pub fn tab2file(\n  uset: USet(a),\n  filename: String,\n  object_count: Bool,\n  md5sum: Bool,\n  sync: Bool,\n) -&gt; Bool\n Saves a `USet` as file `filename` that can later be read back into memory using `file2tab`.\n\n There are three configuration flags with this function:\n - `object_count`: Stores the number of objects in the table in the footer. This can detect truncation.\n - `md5sum`: Stores a md5 checksum of the table and its objects. This can detect even single bitflips, but is computationally expensive.\n - `sync`: Blocks the process until the file has been successfully written.\n\nSynonyms:\nbravo/uset.tab2file\nbravo/uset tab2file","url":"bravo/uset.html#tab2file"},{"doc":"bravo/uset","title":"tab2list","content":"pub fn tab2list(uset: USet(a)) -&gt; List(a)\n Returns a list containing all of the objects in the `USet`.\n\nSynonyms:\nbravo/uset.tab2list\nbravo/uset tab2list","url":"bravo/uset.html#tab2list"},{"doc":"bravo/uset","title":"bravo/uset","content":" This module provides functions to work with `USet`s","url":"bravo/uset.html"}]);